drop _all
clear
clear matrix
set mem 500m
set more off

*** Change these global macros 
	global input 	= "D:\Oxford\KE Education\KE-WEB\Private Schools Paper\INPUT"				// 	Folder where anonymized, raw data is stored	for dissemination
	global output 	= "D:\Oxford\KE Education\KE-WEB\Private Schools Paper\OUTPUT"				//	Folder where all modified data files are saved

use "$input/emis_2005_anonymous.dta", clear

**********************
*** Count teachers ***
**********************

	destring *duty*, replace
	generat teachers = teachersonduty
	replace teachers = dutyteach if teachers==.
	replace teachers = . if teachers==400

********************
*** Count pupils ***
********************	

	*What we start with is very disaggregated: pupils by sex and age per grade: sum to total per school
	*Have to operate at school level, bc can't uniquely match schools to pupils at lower level of aggregation
	forval g = 1/8{
		gen totenrol`g' = .
		foreach s in m f{
			gen totenrol`g'`s' = .
		}
	}
	forval g = 1/8{
		foreach a in b6 6 7 8 9 10 11 12 13 14 a14{
			qui egen temp`g'm = rsum(totenrol`g'm std`g'm`a')
			qui replace totenrol`g'm = temp`g'm
			drop temp`g'm
			qui egen temp`g'f = rsum(totenrol`g'f std`g'f`a')
			qui replace totenrol`g'f = temp`g'f
			drop temp`g'f

			foreach s in m f{
				qui egen temp`g' = rsum(totenrol`g' std`g'`s'`a')
				qui replace totenrol`g'=temp`g'
				drop temp`g'
			}
		}
	}
	forval g = 1/8{
		gen pupilstream`g' = totenrol`g'/std`g'strm
	}

	egen totenrol = rsum( t*1 t*2 t*3 t*4 t*5 t*6 t*7 t*8)
	tabstat t*1 t*2 t*3 t*4 t*5 t*6 t*7 t*8 totenrol, format(%5.1f)
	
	
***********
*** PTR ***
***********
	
	gen ptr = totenrol/teachers
	gen tpr = teachers/totenrol

	keep ptr tpr totenrol teachers
	
	gen funding 	= 1020 + (tpr * 19372 * 12)					// Per pupil funding per annum: KES 1,020 capitation grant + ave monthly TSC salary from KNEC survey x 12 mos. in 2009 KES
	gen fundingUSD 	= funding / 73.98							// June 30, 2009 exrat KES/USD from Oanda.com
	sum ptr tpr fundingUSD
	
save "$output/ptr2005.dta", replace
	
exit

