drop _all
clear
capture clear matrix
set mem 500m
set more off

*** Change these global macros 
	global input 	= "D:\Oxford\KE Education\KE-WEB\Private Schools Paper\INPUT"				// 	Folder where anonymized, raw data is stored	for dissemination
	global output 	= "D:\Oxford\KE Education\KE-WEB\Private Schools Paper\OUTPUT"				//	Folder where all modified data files are saved

use "$input/kcpe_panel_anonymous.dta", clear

****************************
***	Clean up KCPE scores ***
****************************

***	Ignore zeros - not a valid KCPE score
	foreach var of varlist kcpe_eng kcpe_kis kcpe_mat kcpe_sci kcpe_ghc {
			replace `var'=. if `var'==0
	}

***	Total score, aggregating subject-specific tests
	drop kcpe kcpe_b kcpe_g
	gen  kcpe 	= kcpe_eng 	+ kcpe_kis + kcpe_mat + kcpe_sci + kcpe_ghc
	gen  kcpe_b = kcpe_eng_b + kcpe_kis_b + kcpe_mat_b + kcpe_sci_b + kcpe_ghc_b
	gen  kcpe_g = kcpe_eng_g + kcpe_kis_g + kcpe_mat_g + kcpe_sci_g + kcpe_ghc_g

***	Separate dep and ind vars for boys/girls
	foreach var in kcpe enrol{
		gen `var'm = `var'_b 
		gen `var'f = `var'_g 
	}
	
*****************************
*** Clean up school panel ***
*****************************

	duplicates report kneccode year
	assert r(unique_value) == r(N)
	sort kneccode year
	tsset kneccode year
	
*** Alternative depvar that restricts sample to balanced panel of schools, ignoring entry/exit
	duplicates tag kneccode, g(repeats)
	gen kcpe_panelm 	= kcpe_b if repeats==7
	gen kcpe_panelf 	= kcpe_g if repeats==7
	gen enrol_panelm	= enrol_b if repeats==7
	gen enrol_panelf	= enrol_g if repeats==7

save "$output/kcpe_panel_regsample.dta", replace

exit
