use "$output/kcpe_panel_regsample.dta", clear

***************************************************************
*** Table 1: Achievement: Summary Statistics for KCPE Exams ***
***************************************************************

	foreach var in kcpe enrol{
		gen `var'_priv = `var' if private==1
		gen `var'_govt = `var' if private==0
	}
	latabstat kcpe kcpe_govt kcpe_priv [aw=enrol], by(year) s(mean) format(%4.0f)
	latabstat enrol enrol_govt enrol_priv, by(year) s(sum) format(%4.0f)

*******************************************************
*** Figure 1: Right hand panel (CDF of KCPE scores) ***
*******************************************************
	
	gen kcpegovP05 = kcpe if private==0 & year==2005
	gen kcpepriP05 = kcpe if private==1 & year==2005

	cumul kcpegovP05 /*[aw=weight_hh]*/, g(cumgovP05)
	cumul kcpepriP05 /*[aw=weight_hh]*/, g(cumpriP05)

	*** Strange bug here in my method: for repeated values of 1st var below, cumul creates a range of values for 2nd var, but sort fails to put them in the right order, creating spurious non-monotonicities in the CDF
	preserve
	foreach var in govP05 priP05{
		duplicates tag kcpe`var', g(dup)
		drop if dup>0 & kcpe`var'!=.
		drop dup
	}

	twoway 	(line cumpriP05 kcpepriP05 if kcpepriP05>=100, sort lwidth(medium)					)			///
			(line cumgovP05 kcpegovP05 if kcpegovP05>=100, sort lwidth(medium)  lpattern(dash)	),			///	
			ytitle("Cumulative Probability", size(large))													///
			xtitle("KCPE Exam Score", size(large))															///
			legend(order(1 "Private Schools" 2 "Public Schools") size(large) region(lcolor(white)))			///
			graphregion(color(white)) ylabel(, axis(1) grid)
			*title("CDF of KCPE Exam Scores") subtitle("Public & Private Schools, 1998-2005")

	restore


*************************************
*** Create district level dataset ***
*************************************

	keep kcpem kcpef enrolm enrolf kneccode iddist year private kcpe_panelm kcpe_panelf enrol_panelm enrol_panelf

	reshape long kcpe enrol kcpe_panel enrol_panel, i(kneccode year) j(sex) string
		tostring iddist, replace												
		gen iddist_sex 	= iddistrict + sex
		encode iddist_sex, g(cell)
	save "$output/temp.dta", replace

		tab year, g(dumyear)
		gen FPE = year>=2003
		gen privateFPE = private*FPE
reg kcpe private 			dumyear2 - dumyear8 i.cell [pw=enrol], robust cluster(cell)
		est2vec kcperobustness, replace vars(private privateFPE enrol _cons) name(a1)
reg kcpe private privateFPE dumyear2 - dumyear8 i.cell [pw=enrol], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(a2)
		drop dumy*

	preserve
		collapse (mean) kcpe kcpe_panel [pw=enrol], by(cell private year)						//	collapse to MEAN for scores, weighted by enrolment since data is already a school average
		tempfile distkcpe
		sort cell private year
		save `distkcpe', replace
	restore

	collapse (sum) enrol enrol_panel, by(cell private year)										//	collapse to SUM for enrolments
		sort cell private year
	*mmerge cell private year using `distkcpe', unmatched(none)
	merge cell private year using `distkcpe'
		drop if _merge!=3	
		drop _merge

	*** Use 1998 enrolment as weight
		tab year, g(dumyear)
		gen FPE = year>=2003
		gen privateFPE = private*FPE
		
*reg kcpe private 			dumyear2 - dumyear8 i.cell [pw=enrol], robust cluster(cell)
*		est2vec kcperobustness, addto(kcperobustness) name(b1)
*reg kcpe private privateFPE dumyear2 - dumyear8 i.cell [pw=enrol], robust cluster(cell)
*		est2vec kcperobustness, addto(kcperobustness) name(b2)
		drop dumy* privateFPE FPE

		rename kcpe kcpe_all
		rename enrol enrol_all
	reshape wide kcpe_all enrol_all kcpe_panel enrol_panel, i(cell year) j(private) 
		foreach set in all panel{																//	do everything for 2 samples: all schools and panel schools
			forval t = 0/1{
				replace kcpe_`set'`t'  = 0 if kcpe_`set'`t'==.
				replace enrol_`set'`t' = 0 if enrol_`set'`t'==.
			}			
			gen enrol_`set' 		= (enrol_`set'0 + enrol_`set'1)/1000
			gen enrol2_`set'		= enrol_`set'^2
			gen enrolpshare_`set' 	= enrol_`set'1/(enrol_`set'*1000)
			gen enrolpshare2_`set'	= enrolpshare_`set'^2
			gen kcpe_`set' 			= (kcpe_`set'0*enrol_`set'0  + kcpe_`set'1*enrol_`set'1)/(enrol_`set'*1000)
			gen kcperelative_`set'  = kcpe_`set'1/kcpe_`set'0
		}
		sort cell year
		tsset cell year
		foreach var in kcpe enrolpshare enrolpshare2 enrol enrol2{
			foreach set in all panel{
				gen D`var'_`set' = D.`var'_`set'
				gen l_`var'_`set' = l.`var'_`set'
				gen f_`var'_`set' = f.`var'_`set' 
			}
		}
		gen FPE = year>=2003
		tab year, g(dumyear)
		label define FPE 0 "Before" 1 "After"
		label values FPE FPE

	*** Weights must be constant within distcode_sex (used for FE)
	*** So use 1998 enrolment as weight, so that predicted values sum back to 247
		gen enrol98 = enrol_all if year==1998
		bysort cell: egen weight = mean(enrol98)
	save "$output/temp2.dta", replace


****************
*** Outliers ***
****************

	bysort cell: egen maxDkcpe_all 		= max(abs(Dkcpe_all))		
	bysort cell: egen maxDkcpe_panel 	= max(abs(Dkcpe_panel))
	bysort cell: egen maxDenrol_all 	= max(abs(Denrolpshare_all))
	bysort cell: egen maxDenrol_panel 	= max(abs(Denrolpshare_panel))

************************************
*** Main achievement regressions ***
************************************

		foreach var in kcpe enrolpshare enrol enrolpshare2 enrol2{
			gen `var' = `var'_all
		}
		gen enrolpshareFPE = enrolpshare*FPE
		label variable enrolpshareFPE	"Private school share $ \times$ FPE"
		label variable enrolpshare 		"Private school share"
		label variable enrolpshare2 	"Private school share sq."
		label variable enrol 			"Total enrolment"
		label variable enrol2 			"Total enrolment sq."
		
		gen private = enrolpshare
		gen privateFPE = enrolpshareFPE
		
*** New version of achievement table, April 21, 2011
	reg kcpe private dumyear2 - dumyear8 i.cell [pw=enrol_all], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(c1)
	reg kcpe private privateFPE dumyear2 - dumyear8 i.cell [pw=enrol_all], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(c2)
	reg kcpe private privateFPE enrol dumyear2 - dumyear8 i.cell [pw=enrol_all], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(c3)

		drop if maxDenrol_all>.071													//	Dropping districts with 1% of largest absolute changes in private enrolment shares and KCPE; only 1 of these districts is clear data error (801)
		drop if maxDkcpe_all>21.8029

	reg kcpe 	 private privateFPE enrol dumyear2 - dumyear8 i.cell [pw=enrol_all], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(c4)
	reg kcpe_panel private privateFPE enrol dumyear2 - dumyear8 i.cell [pw=enrol_all], robust cluster(cell)
		est2vec kcperobustness, addto(kcperobustness) name(c5)
		est2tex kcperobustness, preserve path("$output") levels (90 95 99) fancy replace digits(1) mark(stars) extracol(2 4)

exit

